@@ -284,6 +284,7 @@
                       logitBoost = data.frame(.nIter =  floor((1:len) * 50)),
                       J48 = data.frame(.C = 0.25),
                       M5Rules = data.frame(.pruned = c("Yes", "No"), .smoothed = "Yes"),
+                      M5 = expand.grid(.pruned = c("Yes", "No"), .smoothed = c("Yes", "No"), .rules = c("Yes", "No")),
                       LMT = data.frame(.iter = (1:len) * 20),
                       JRip = data.frame(.NumOpt = 1:len),
                       superpc = expand.grid(.n.components = 1:3,
@@ -339,6 +340,8 @@
                                 .penalty = c(0, 10 ^ seq(-1, -4, length = len - 1)),
                                 .bag = FALSE),
                       cubist = expand.grid(.committees = c(1, 10, 20), .neighbors = c(0, 5, 9)),
+                      bstTree = expand.grid(.maxdepth = seq(1, len), .mstop = floor((1:len) * 50), .nu = .1),
+                      bstLs =, bstSm =  expand.grid(.mstop = floor((1:len) * 50), .nu = .1),
                       lda =, lm =, treebag =, sddaLDA =, sddaQDA =,
                       glm =, qda =, OneR =, rlm =,
                       rvmLinear =, lssvmLinear =, gaussprLinear =,
